| Title: | Shiny app for online lecture support with chat and quizzes |
|---|---|
| Description: | Shiny app for online lecture support with chat and quizzes |
| Authors: | Sebastian Kranz |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 2.0 |
| Version: | 0.1.0 |
| Built: | 2026-05-24 08:53:49 UTC |
| Source: | https://github.com/skranz/shinyChatQuiz |